# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class DanishStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"hed", -1, 1),
        Among(u"ethed", 0, 1),
        Among(u"ered", -1, 1),
        Among(u"e", -1, 1),
        Among(u"erede", 3, 1),
        Among(u"ende", 3, 1),
        Among(u"erende", 5, 1),
        Among(u"ene", 3, 1),
        Among(u"erne", 3, 1),
        Among(u"ere", 3, 1),
        Among(u"en", -1, 1),
        Among(u"heden", 10, 1),
        Among(u"eren", 10, 1),
        Among(u"er", -1, 1),
        Among(u"heder", 13, 1),
        Among(u"erer", 13, 1),
        Among(u"s", -1, 2),
        Among(u"heds", 16, 1),
        Among(u"es", 16, 1),
        Among(u"endes", 18, 1),
        Among(u"erendes", 19, 1),
        Among(u"enes", 18, 1),
        Among(u"ernes", 18, 1),
        Among(u"eres", 18, 1),
        Among(u"ens", 16, 1),
        Among(u"hedens", 24, 1),
        Among(u"erens", 24, 1),
        Among(u"ers", 16, 1),
        Among(u"ets", 16, 1),
        Among(u"erets", 28, 1),
        Among(u"et", -1, 1),
        Among(u"eret", 30, 1)
    ]

    a_1 = [
        Among(u"gd", -1, -1),
        Among(u"dt", -1, -1),
        Among(u"gt", -1, -1),
        Among(u"kt", -1, -1)
    ]

    a_2 = [
        Among(u"ig", -1, 1),
        Among(u"lig", 0, 1),
        Among(u"elig", 1, 1),
        Among(u"els", -1, 1),
        Among(u"l\u00F8st", -1, 2)
    ]

    g_c = [119, 223, 119, 1]

    g_v = [17, 65, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 0, 128]

    g_s_ending = [239, 254, 42, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16]

    I_x = 0
    I_p1 = 0
    S_ch = ""


    def __r_mark_regions(self):
        # (, line 31
        self.I_p1 = self.limit
        # test, line 35
        v_1 = self.cursor
        # (, line 35
        # hop, line 35
        c = self.cursor + 3
        if 0 > c or c > self.limit:
            return False
        self.cursor = c
        # setmark x, line 35
        self.I_x = self.cursor
        self.cursor = v_1
        # goto, line 36
        try:
            while True:
                v_2 = self.cursor
                try:
                    if not self.in_grouping(DanishStemmer.g_v, 97, 248):
                        raise lab1()
                    self.cursor = v_2
                    raise lab0()
                except lab1: pass
                self.cursor = v_2
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab0: pass
        # gopast, line 36
        try:
            while True:
                try:
                    if not self.out_grouping(DanishStemmer.g_v, 97, 248):
                        raise lab3()
                    raise lab2()
                except lab3: pass
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab2: pass
        # setmark p1, line 36
        self.I_p1 = self.cursor
        # try, line 37
        try:
            # (, line 37
            if not self.I_p1 < self.I_x:
                raise lab4()
            self.I_p1 = self.I_x
        except lab4: pass
        return True

    def __r_main_suffix(self):
        # (, line 42
        # setlimit, line 43
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 43
        # [, line 43
        self.ket = self.cursor
        # substring, line 43
        among_var = self.find_among_b(DanishStemmer.a_0)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        # ], line 43
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            # (, line 50
            # delete, line 50
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 52
            if not self.in_grouping_b(DanishStemmer.g_s_ending, 97, 229):
                return False
            # delete, line 52
            if not self.slice_del():
                return False

        return True

    def __r_consonant_pair(self):
        # (, line 56
        # test, line 57
        v_1 = self.limit - self.cursor
        # (, line 57
        # setlimit, line 58
        if self.cursor < self.I_p1:
            return False
        v_3 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 58
        # [, line 58
        self.ket = self.cursor
        # substring, line 58
        if self.find_among_b(DanishStemmer.a_1) == 0:
            self.limit_backward = v_3
            return False
        # ], line 58
        self.bra = self.cursor
        self.limit_backward = v_3
        self.cursor = self.limit - v_1
        # next, line 64
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        # ], line 64
        self.bra = self.cursor
        # delete, line 64
        if not self.slice_del():
            return False

        return True

    def __r_other_suffix(self):
        # (, line 67
        # do, line 68
        v_1 = self.limit - self.cursor
        try:
            # (, line 68
            # [, line 68
            self.ket = self.cursor
            # literal, line 68
            if not self.eq_s_b(u"st"):
                raise lab0()
            # ], line 68
            self.bra = self.cursor
            # literal, line 68
            if not self.eq_s_b(u"ig"):
                raise lab0()
            # delete, line 68
            if not self.slice_del():
                return False

        except lab0: pass
        self.cursor = self.limit - v_1
        # setlimit, line 69
        if self.cursor < self.I_p1:
            return False
        v_3 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 69
        # [, line 69
        self.ket = self.cursor
        # substring, line 69
        among_var = self.find_among_b(DanishStemmer.a_2)
        if among_var == 0:
            self.limit_backward = v_3
            return False
        # ], line 69
        self.bra = self.cursor
        self.limit_backward = v_3
        if among_var == 1:
            # (, line 72
            # delete, line 72
            if not self.slice_del():
                return False

            # do, line 72
            v_4 = self.limit - self.cursor
            # call consonant_pair, line 72
            self.__r_consonant_pair()
            self.cursor = self.limit - v_4
        elif among_var == 2:
            # (, line 74
            # <-, line 74
            if not self.slice_from(u"l\u00F8s"):
                return False
        return True

    def __r_undouble(self):
        # (, line 77
        # setlimit, line 78
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 78
        # [, line 78
        self.ket = self.cursor
        if not self.in_grouping_b(DanishStemmer.g_c, 98, 122):
            self.limit_backward = v_2
            return False
        # ], line 78
        self.bra = self.cursor
        # -> ch, line 78
        self.S_ch = self.slice_to()
        if self.S_ch == '':
            return False
        self.limit_backward = v_2
        # name ch, line 79
        if not self.eq_s_b(self.S_ch):
            return False
        # delete, line 80
        if not self.slice_del():
            return False

        return True

    def _stem(self):
        # (, line 84
        # do, line 86
        v_1 = self.cursor
        # call mark_regions, line 86
        self.__r_mark_regions()
        self.cursor = v_1
        # backwards, line 87
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # (, line 87
        # do, line 88
        v_2 = self.limit - self.cursor
        # call main_suffix, line 88
        self.__r_main_suffix()
        self.cursor = self.limit - v_2
        # do, line 89
        v_3 = self.limit - self.cursor
        # call consonant_pair, line 89
        self.__r_consonant_pair()
        self.cursor = self.limit - v_3
        # do, line 90
        v_4 = self.limit - self.cursor
        # call other_suffix, line 90
        self.__r_other_suffix()
        self.cursor = self.limit - v_4
        # do, line 91
        v_5 = self.limit - self.cursor
        # call undouble, line 91
        self.__r_undouble()
        self.cursor = self.limit - v_5
        self.cursor = self.limit_backward
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass



# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class RussianStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"\u0432", -1, 1),
        Among(u"\u0438\u0432", 0, 2),
        Among(u"\u044B\u0432", 0, 2),
        Among(u"\u0432\u0448\u0438", -1, 1),
        Among(u"\u0438\u0432\u0448\u0438", 3, 2),
        Among(u"\u044B\u0432\u0448\u0438", 3, 2),
        Among(u"\u0432\u0448\u0438\u0441\u044C", -1, 1),
        Among(u"\u0438\u0432\u0448\u0438\u0441\u044C", 6, 2),
        Among(u"\u044B\u0432\u0448\u0438\u0441\u044C", 6, 2)
    ]

    a_1 = [
        Among(u"\u0435\u0435", -1, 1),
        Among(u"\u0438\u0435", -1, 1),
        Among(u"\u043E\u0435", -1, 1),
        Among(u"\u044B\u0435", -1, 1),
        Among(u"\u0438\u043C\u0438", -1, 1),
        Among(u"\u044B\u043C\u0438", -1, 1),
        Among(u"\u0435\u0439", -1, 1),
        Among(u"\u0438\u0439", -1, 1),
        Among(u"\u043E\u0439", -1, 1),
        Among(u"\u044B\u0439", -1, 1),
        Among(u"\u0435\u043C", -1, 1),
        Among(u"\u0438\u043C", -1, 1),
        Among(u"\u043E\u043C", -1, 1),
        Among(u"\u044B\u043C", -1, 1),
        Among(u"\u0435\u0433\u043E", -1, 1),
        Among(u"\u043E\u0433\u043E", -1, 1),
        Among(u"\u0435\u043C\u0443", -1, 1),
        Among(u"\u043E\u043C\u0443", -1, 1),
        Among(u"\u0438\u0445", -1, 1),
        Among(u"\u044B\u0445", -1, 1),
        Among(u"\u0435\u044E", -1, 1),
        Among(u"\u043E\u044E", -1, 1),
        Among(u"\u0443\u044E", -1, 1),
        Among(u"\u044E\u044E", -1, 1),
        Among(u"\u0430\u044F", -1, 1),
        Among(u"\u044F\u044F", -1, 1)
    ]

    a_2 = [
        Among(u"\u0435\u043C", -1, 1),
        Among(u"\u043D\u043D", -1, 1),
        Among(u"\u0432\u0448", -1, 1),
        Among(u"\u0438\u0432\u0448", 2, 2),
        Among(u"\u044B\u0432\u0448", 2, 2),
        Among(u"\u0449", -1, 1),
        Among(u"\u044E\u0449", 5, 1),
        Among(u"\u0443\u044E\u0449", 6, 2)
    ]

    a_3 = [
        Among(u"\u0441\u044C", -1, 1),
        Among(u"\u0441\u044F", -1, 1)
    ]

    a_4 = [
        Among(u"\u043B\u0430", -1, 1),
        Among(u"\u0438\u043B\u0430", 0, 2),
        Among(u"\u044B\u043B\u0430", 0, 2),
        Among(u"\u043D\u0430", -1, 1),
        Among(u"\u0435\u043D\u0430", 3, 2),
        Among(u"\u0435\u0442\u0435", -1, 1),
        Among(u"\u0438\u0442\u0435", -1, 2),
        Among(u"\u0439\u0442\u0435", -1, 1),
        Among(u"\u0435\u0439\u0442\u0435", 7, 2),
        Among(u"\u0443\u0439\u0442\u0435", 7, 2),
        Among(u"\u043B\u0438", -1, 1),
        Among(u"\u0438\u043B\u0438", 10, 2),
        Among(u"\u044B\u043B\u0438", 10, 2),
        Among(u"\u0439", -1, 1),
        Among(u"\u0435\u0439", 13, 2),
        Among(u"\u0443\u0439", 13, 2),
        Among(u"\u043B", -1, 1),
        Among(u"\u0438\u043B", 16, 2),
        Among(u"\u044B\u043B", 16, 2),
        Among(u"\u0435\u043C", -1, 1),
        Among(u"\u0438\u043C", -1, 2),
        Among(u"\u044B\u043C", -1, 2),
        Among(u"\u043D", -1, 1),
        Among(u"\u0435\u043D", 22, 2),
        Among(u"\u043B\u043E", -1, 1),
        Among(u"\u0438\u043B\u043E", 24, 2),
        Among(u"\u044B\u043B\u043E", 24, 2),
        Among(u"\u043D\u043E", -1, 1),
        Among(u"\u0435\u043D\u043E", 27, 2),
        Among(u"\u043D\u043D\u043E", 27, 1),
        Among(u"\u0435\u0442", -1, 1),
        Among(u"\u0443\u0435\u0442", 30, 2),
        Among(u"\u0438\u0442", -1, 2),
        Among(u"\u044B\u0442", -1, 2),
        Among(u"\u044E\u0442", -1, 1),
        Among(u"\u0443\u044E\u0442", 34, 2),
        Among(u"\u044F\u0442", -1, 2),
        Among(u"\u043D\u044B", -1, 1),
        Among(u"\u0435\u043D\u044B", 37, 2),
        Among(u"\u0442\u044C", -1, 1),
        Among(u"\u0438\u0442\u044C", 39, 2),
        Among(u"\u044B\u0442\u044C", 39, 2),
        Among(u"\u0435\u0448\u044C", -1, 1),
        Among(u"\u0438\u0448\u044C", -1, 2),
        Among(u"\u044E", -1, 2),
        Among(u"\u0443\u044E", 44, 2)
    ]

    a_5 = [
        Among(u"\u0430", -1, 1),
        Among(u"\u0435\u0432", -1, 1),
        Among(u"\u043E\u0432", -1, 1),
        Among(u"\u0435", -1, 1),
        Among(u"\u0438\u0435", 3, 1),
        Among(u"\u044C\u0435", 3, 1),
        Among(u"\u0438", -1, 1),
        Among(u"\u0435\u0438", 6, 1),
        Among(u"\u0438\u0438", 6, 1),
        Among(u"\u0430\u043C\u0438", 6, 1),
        Among(u"\u044F\u043C\u0438", 6, 1),
        Among(u"\u0438\u044F\u043C\u0438", 10, 1),
        Among(u"\u0439", -1, 1),
        Among(u"\u0435\u0439", 12, 1),
        Among(u"\u0438\u0435\u0439", 13, 1),
        Among(u"\u0438\u0439", 12, 1),
        Among(u"\u043E\u0439", 12, 1),
        Among(u"\u0430\u043C", -1, 1),
        Among(u"\u0435\u043C", -1, 1),
        Among(u"\u0438\u0435\u043C", 18, 1),
        Among(u"\u043E\u043C", -1, 1),
        Among(u"\u044F\u043C", -1, 1),
        Among(u"\u0438\u044F\u043C", 21, 1),
        Among(u"\u043E", -1, 1),
        Among(u"\u0443", -1, 1),
        Among(u"\u0430\u0445", -1, 1),
        Among(u"\u044F\u0445", -1, 1),
        Among(u"\u0438\u044F\u0445", 26, 1),
        Among(u"\u044B", -1, 1),
        Among(u"\u044C", -1, 1),
        Among(u"\u044E", -1, 1),
        Among(u"\u0438\u044E", 30, 1),
        Among(u"\u044C\u044E", 30, 1),
        Among(u"\u044F", -1, 1),
        Among(u"\u0438\u044F", 33, 1),
        Among(u"\u044C\u044F", 33, 1)
    ]

    a_6 = [
        Among(u"\u043E\u0441\u0442", -1, 1),
        Among(u"\u043E\u0441\u0442\u044C", -1, 1)
    ]

    a_7 = [
        Among(u"\u0435\u0439\u0448\u0435", -1, 1),
        Among(u"\u043D", -1, 2),
        Among(u"\u0435\u0439\u0448", -1, 1),
        Among(u"\u044C", -1, 3)
    ]

    g_v = [33, 65, 8, 232]

    I_p2 = 0
    I_pV = 0


    def __r_mark_regions(self):
        # (, line 59
        self.I_pV = self.limit
        self.I_p2 = self.limit
        # do, line 63
        v_1 = self.cursor
        try:
            # (, line 63
            # gopast, line 64
            try:
                while True:
                    try:
                        if not self.in_grouping(RussianStemmer.g_v, 1072, 1103):
                            raise lab2()
                        raise lab1()
                    except lab2: pass
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
            except lab1: pass
            # setmark pV, line 64
            self.I_pV = self.cursor
            # gopast, line 64
            try:
                while True:
                    try:
                        if not self.out_grouping(RussianStemmer.g_v, 1072, 1103):
                            raise lab4()
                        raise lab3()
                    except lab4: pass
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
            except lab3: pass
            # gopast, line 65
            try:
                while True:
                    try:
                        if not self.in_grouping(RussianStemmer.g_v, 1072, 1103):
                            raise lab6()
                        raise lab5()
                    except lab6: pass
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
            except lab5: pass
            # gopast, line 65
            try:
                while True:
                    try:
                        if not self.out_grouping(RussianStemmer.g_v, 1072, 1103):
                            raise lab8()
                        raise lab7()
                    except lab8: pass
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
            except lab7: pass
            # setmark p2, line 65
            self.I_p2 = self.cursor
        except lab0: pass
        self.cursor = v_1
        return True

    def __r_R2(self):
        if not self.I_p2 <= self.cursor:
            return False
        return True

    def __r_perfective_gerund(self):
        # (, line 73
        # [, line 74
        self.ket = self.cursor
        # substring, line 74
        among_var = self.find_among_b(RussianStemmer.a_0)
        if among_var == 0:
            return False
        # ], line 74
        self.bra = self.cursor
        if among_var == 1:
            # (, line 78
            # or, line 78
            try:
                v_1 = self.limit - self.cursor
                try:
                    # literal, line 78
                    if not self.eq_s_b(u"\u0430"):
                        raise lab1()
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_1
                # literal, line 78
                if not self.eq_s_b(u"\u044F"):
                    return False
            except lab0: pass
            # delete, line 78
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 85
            # delete, line 85
            if not self.slice_del():
                return False

        return True

    def __r_adjective(self):
        # (, line 89
        # [, line 90
        self.ket = self.cursor
        # substring, line 90
        if self.find_among_b(RussianStemmer.a_1) == 0:
            return False
        # ], line 90
        self.bra = self.cursor
        # (, line 99
        # delete, line 99
        if not self.slice_del():
            return False

        return True

    def __r_adjectival(self):
        # (, line 103
        # call adjective, line 104
        if not self.__r_adjective():
            return False
        # try, line 111
        v_1 = self.limit - self.cursor
        try:
            # (, line 111
            # [, line 112
            self.ket = self.cursor
            # substring, line 112
            among_var = self.find_among_b(RussianStemmer.a_2)
            if among_var == 0:
                self.cursor = self.limit - v_1
                raise lab0()
            # ], line 112
            self.bra = self.cursor
            if among_var == 1:
                # (, line 117
                # or, line 117
                try:
                    v_2 = self.limit - self.cursor
                    try:
                        # literal, line 117
                        if not self.eq_s_b(u"\u0430"):
                            raise lab2()
                        raise lab1()
                    except lab2: pass
                    self.cursor = self.limit - v_2
                    # literal, line 117
                    if not self.eq_s_b(u"\u044F"):
                        self.cursor = self.limit - v_1
                        raise lab0()
                except lab1: pass
                # delete, line 117
                if not self.slice_del():
                    return False

            elif among_var == 2:
                # (, line 124
                # delete, line 124
                if not self.slice_del():
                    return False

        except lab0: pass
        return True

    def __r_reflexive(self):
        # (, line 130
        # [, line 131
        self.ket = self.cursor
        # substring, line 131
        if self.find_among_b(RussianStemmer.a_3) == 0:
            return False
        # ], line 131
        self.bra = self.cursor
        # (, line 134
        # delete, line 134
        if not self.slice_del():
            return False

        return True

    def __r_verb(self):
        # (, line 138
        # [, line 139
        self.ket = self.cursor
        # substring, line 139
        among_var = self.find_among_b(RussianStemmer.a_4)
        if among_var == 0:
            return False
        # ], line 139
        self.bra = self.cursor
        if among_var == 1:
            # (, line 145
            # or, line 145
            try:
                v_1 = self.limit - self.cursor
                try:
                    # literal, line 145
                    if not self.eq_s_b(u"\u0430"):
                        raise lab1()
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_1
                # literal, line 145
                if not self.eq_s_b(u"\u044F"):
                    return False
            except lab0: pass
            # delete, line 145
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 153
            # delete, line 153
            if not self.slice_del():
                return False

        return True

    def __r_noun(self):
        # (, line 161
        # [, line 162
        self.ket = self.cursor
        # substring, line 162
        if self.find_among_b(RussianStemmer.a_5) == 0:
            return False
        # ], line 162
        self.bra = self.cursor
        # (, line 169
        # delete, line 169
        if not self.slice_del():
            return False

        return True

    def __r_derivational(self):
        # (, line 177
        # [, line 178
        self.ket = self.cursor
        # substring, line 178
        if self.find_among_b(RussianStemmer.a_6) == 0:
            return False
        # ], line 178
        self.bra = self.cursor
        # call R2, line 178
        if not self.__r_R2():
            return False
        # (, line 181
        # delete, line 181
        if not self.slice_del():
            return False

        return True

    def __r_tidy_up(self):
        # (, line 185
        # [, line 186
        self.ket = self.cursor
        # substring, line 186
        among_var = self.find_among_b(RussianStemmer.a_7)
        if among_var == 0:
            return False
        # ], line 186
        self.bra = self.cursor
        if among_var == 1:
            # (, line 190
            # delete, line 190
            if not self.slice_del():
                return False

            # [, line 191
            self.ket = self.cursor
            # literal, line 191
            if not self.eq_s_b(u"\u043D"):
                return False
            # ], line 191
            self.bra = self.cursor
            # literal, line 191
            if not self.eq_s_b(u"\u043D"):
                return False
            # delete, line 191
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 194
            # literal, line 194
            if not self.eq_s_b(u"\u043D"):
                return False
            # delete, line 194
            if not self.slice_del():
                return False

        elif among_var == 3:
            # (, line 196
            # delete, line 196
            if not self.slice_del():
                return False

        return True

    def _stem(self):
        # (, line 201
        # do, line 205
        v_1 = self.cursor
        try:
            # repeat, line 205
            try:
                while True:
                    try:
                        v_2 = self.cursor
                        try:
                            # (, line 205
                            # goto, line 205
                            try:
                                while True:
                                    v_3 = self.cursor
                                    try:
                                        # (, line 205
                                        # [, line 205
                                        self.bra = self.cursor
                                        # literal, line 205
                                        if not self.eq_s(u"\u0451"):
                                            raise lab5()
                                        # ], line 205
                                        self.ket = self.cursor
                                        self.cursor = v_3
                                        raise lab4()
                                    except lab5: pass
                                    self.cursor = v_3
                                    if self.cursor >= self.limit:
                                        raise lab3()
                                    self.cursor += 1
                            except lab4: pass
                            # <-, line 205
                            if not self.slice_from(u"\u0435"):
                                return False
                            raise lab2()
                        except lab3: pass
                        self.cursor = v_2
                        raise lab1()
                    except lab2: pass
            except lab1: pass
        except lab0: pass
        self.cursor = v_1
        # do, line 207
        # call mark_regions, line 207
        self.__r_mark_regions()
        # backwards, line 208
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # setlimit, line 208
        if self.cursor < self.I_pV:
            return False
        v_6 = self.limit_backward
        self.limit_backward = self.I_pV
        # (, line 208
        # do, line 209
        v_7 = self.limit - self.cursor
        try:
            # (, line 209
            # or, line 210
            try:
                v_8 = self.limit - self.cursor
                try:
                    # call perfective_gerund, line 210
                    if not self.__r_perfective_gerund():
                        raise lab8()
                    raise lab7()
                except lab8: pass
                self.cursor = self.limit - v_8
                # (, line 211
                # try, line 211
                v_9 = self.limit - self.cursor
                try:
                    # call reflexive, line 211
                    if not self.__r_reflexive():
                        self.cursor = self.limit - v_9
                        raise lab9()
                except lab9: pass
                # or, line 212
                try:
                    v_10 = self.limit - self.cursor
                    try:
                        # call adjectival, line 212
                        if not self.__r_adjectival():
                            raise lab11()
                        raise lab10()
                    except lab11: pass
                    self.cursor = self.limit - v_10
                    try:
                        # call verb, line 212
                        if not self.__r_verb():
                            raise lab12()
                        raise lab10()
                    except lab12: pass
                    self.cursor = self.limit - v_10
                    # call noun, line 212
                    if not self.__r_noun():
                        raise lab6()
                except lab10: pass
            except lab7: pass
        except lab6: pass
        self.cursor = self.limit - v_7
        # try, line 215
        v_11 = self.limit - self.cursor
        try:
            # (, line 215
            # [, line 215
            self.ket = self.cursor
            # literal, line 215
            if not self.eq_s_b(u"\u0438"):
                self.cursor = self.limit - v_11
                raise lab13()
            # ], line 215
            self.bra = self.cursor
            # delete, line 215
            if not self.slice_del():
                return False

        except lab13: pass
        # do, line 218
        v_12 = self.limit - self.cursor
        # call derivational, line 218
        self.__r_derivational()
        self.cursor = self.limit - v_12
        # do, line 219
        v_13 = self.limit - self.cursor
        # call tidy_up, line 219
        self.__r_tidy_up()
        self.cursor = self.limit - v_13
        self.limit_backward = v_6
        self.cursor = self.limit_backward
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass


class lab5(BaseException): pass


class lab6(BaseException): pass


class lab7(BaseException): pass


class lab8(BaseException): pass


class lab9(BaseException): pass


class lab10(BaseException): pass


class lab11(BaseException): pass


class lab12(BaseException): pass


class lab13(BaseException): pass



# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class NorwegianStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"a", -1, 1),
        Among(u"e", -1, 1),
        Among(u"ede", 1, 1),
        Among(u"ande", 1, 1),
        Among(u"ende", 1, 1),
        Among(u"ane", 1, 1),
        Among(u"ene", 1, 1),
        Among(u"hetene", 6, 1),
        Among(u"erte", 1, 3),
        Among(u"en", -1, 1),
        Among(u"heten", 9, 1),
        Among(u"ar", -1, 1),
        Among(u"er", -1, 1),
        Among(u"heter", 12, 1),
        Among(u"s", -1, 2),
        Among(u"as", 14, 1),
        Among(u"es", 14, 1),
        Among(u"edes", 16, 1),
        Among(u"endes", 16, 1),
        Among(u"enes", 16, 1),
        Among(u"hetenes", 19, 1),
        Among(u"ens", 14, 1),
        Among(u"hetens", 21, 1),
        Among(u"ers", 14, 1),
        Among(u"ets", 14, 1),
        Among(u"et", -1, 1),
        Among(u"het", 25, 1),
        Among(u"ert", -1, 3),
        Among(u"ast", -1, 1)
    ]

    a_1 = [
        Among(u"dt", -1, -1),
        Among(u"vt", -1, -1)
    ]

    a_2 = [
        Among(u"leg", -1, 1),
        Among(u"eleg", 0, 1),
        Among(u"ig", -1, 1),
        Among(u"eig", 2, 1),
        Among(u"lig", 2, 1),
        Among(u"elig", 4, 1),
        Among(u"els", -1, 1),
        Among(u"lov", -1, 1),
        Among(u"elov", 7, 1),
        Among(u"slov", 7, 1),
        Among(u"hetslov", 9, 1)
    ]

    g_v = [17, 65, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 0, 128]

    g_s_ending = [119, 125, 149, 1]

    I_x = 0
    I_p1 = 0


    def __r_mark_regions(self):
        # (, line 26
        self.I_p1 = self.limit
        # test, line 30
        v_1 = self.cursor
        # (, line 30
        # hop, line 30
        c = self.cursor + 3
        if 0 > c or c > self.limit:
            return False
        self.cursor = c
        # setmark x, line 30
        self.I_x = self.cursor
        self.cursor = v_1
        # goto, line 31
        try:
            while True:
                v_2 = self.cursor
                try:
                    if not self.in_grouping(NorwegianStemmer.g_v, 97, 248):
                        raise lab1()
                    self.cursor = v_2
                    raise lab0()
                except lab1: pass
                self.cursor = v_2
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab0: pass
        # gopast, line 31
        try:
            while True:
                try:
                    if not self.out_grouping(NorwegianStemmer.g_v, 97, 248):
                        raise lab3()
                    raise lab2()
                except lab3: pass
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab2: pass
        # setmark p1, line 31
        self.I_p1 = self.cursor
        # try, line 32
        try:
            # (, line 32
            if not self.I_p1 < self.I_x:
                raise lab4()
            self.I_p1 = self.I_x
        except lab4: pass
        return True

    def __r_main_suffix(self):
        # (, line 37
        # setlimit, line 38
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 38
        # [, line 38
        self.ket = self.cursor
        # substring, line 38
        among_var = self.find_among_b(NorwegianStemmer.a_0)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        # ], line 38
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            # (, line 44
            # delete, line 44
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 46
            # or, line 46
            try:
                v_3 = self.limit - self.cursor
                try:
                    if not self.in_grouping_b(NorwegianStemmer.g_s_ending, 98, 122):
                        raise lab1()
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_3
                # (, line 46
                # literal, line 46
                if not self.eq_s_b(u"k"):
                    return False
                if not self.out_grouping_b(NorwegianStemmer.g_v, 97, 248):
                    return False
            except lab0: pass
            # delete, line 46
            if not self.slice_del():
                return False

        elif among_var == 3:
            # (, line 48
            # <-, line 48
            if not self.slice_from(u"er"):
                return False
        return True

    def __r_consonant_pair(self):
        # (, line 52
        # test, line 53
        v_1 = self.limit - self.cursor
        # (, line 53
        # setlimit, line 54
        if self.cursor < self.I_p1:
            return False
        v_3 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 54
        # [, line 54
        self.ket = self.cursor
        # substring, line 54
        if self.find_among_b(NorwegianStemmer.a_1) == 0:
            self.limit_backward = v_3
            return False
        # ], line 54
        self.bra = self.cursor
        self.limit_backward = v_3
        self.cursor = self.limit - v_1
        # next, line 59
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        # ], line 59
        self.bra = self.cursor
        # delete, line 59
        if not self.slice_del():
            return False

        return True

    def __r_other_suffix(self):
        # (, line 62
        # setlimit, line 63
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        # (, line 63
        # [, line 63
        self.ket = self.cursor
        # substring, line 63
        if self.find_among_b(NorwegianStemmer.a_2) == 0:
            self.limit_backward = v_2
            return False
        # ], line 63
        self.bra = self.cursor
        self.limit_backward = v_2
        # (, line 67
        # delete, line 67
        if not self.slice_del():
            return False

        return True

    def _stem(self):
        # (, line 72
        # do, line 74
        v_1 = self.cursor
        # call mark_regions, line 74
        self.__r_mark_regions()
        self.cursor = v_1
        # backwards, line 75
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # (, line 75
        # do, line 76
        v_2 = self.limit - self.cursor
        # call main_suffix, line 76
        self.__r_main_suffix()
        self.cursor = self.limit - v_2
        # do, line 77
        v_3 = self.limit - self.cursor
        # call consonant_pair, line 77
        self.__r_consonant_pair()
        self.cursor = self.limit - v_3
        # do, line 78
        v_4 = self.limit - self.cursor
        # call other_suffix, line 78
        self.__r_other_suffix()
        self.cursor = self.limit - v_4
        self.cursor = self.limit_backward
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass



# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class IrishStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"b'", -1, 1),
        Among(u"bh", -1, 4),
        Among(u"bhf", 1, 2),
        Among(u"bp", -1, 8),
        Among(u"ch", -1, 5),
        Among(u"d'", -1, 1),
        Among(u"d'fh", 5, 2),
        Among(u"dh", -1, 6),
        Among(u"dt", -1, 9),
        Among(u"fh", -1, 2),
        Among(u"gc", -1, 5),
        Among(u"gh", -1, 7),
        Among(u"h-", -1, 1),
        Among(u"m'", -1, 1),
        Among(u"mb", -1, 4),
        Among(u"mh", -1, 10),
        Among(u"n-", -1, 1),
        Among(u"nd", -1, 6),
        Among(u"ng", -1, 7),
        Among(u"ph", -1, 8),
        Among(u"sh", -1, 3),
        Among(u"t-", -1, 1),
        Among(u"th", -1, 9),
        Among(u"ts", -1, 3)
    ]

    a_1 = [
        Among(u"\u00EDochta", -1, 1),
        Among(u"a\u00EDochta", 0, 1),
        Among(u"ire", -1, 2),
        Among(u"aire", 2, 2),
        Among(u"abh", -1, 1),
        Among(u"eabh", 4, 1),
        Among(u"ibh", -1, 1),
        Among(u"aibh", 6, 1),
        Among(u"amh", -1, 1),
        Among(u"eamh", 8, 1),
        Among(u"imh", -1, 1),
        Among(u"aimh", 10, 1),
        Among(u"\u00EDocht", -1, 1),
        Among(u"a\u00EDocht", 12, 1),
        Among(u"ir\u00ED", -1, 2),
        Among(u"air\u00ED", 14, 2)
    ]

    a_2 = [
        Among(u"\u00F3ideacha", -1, 6),
        Among(u"patacha", -1, 5),
        Among(u"achta", -1, 1),
        Among(u"arcachta", 2, 2),
        Among(u"eachta", 2, 1),
        Among(u"grafa\u00EDochta", -1, 4),
        Among(u"paite", -1, 5),
        Among(u"ach", -1, 1),
        Among(u"each", 7, 1),
        Among(u"\u00F3ideach", 8, 6),
        Among(u"gineach", 8, 3),
        Among(u"patach", 7, 5),
        Among(u"grafa\u00EDoch", -1, 4),
        Among(u"pataigh", -1, 5),
        Among(u"\u00F3idigh", -1, 6),
        Among(u"acht\u00FAil", -1, 1),
        Among(u"eacht\u00FAil", 15, 1),
        Among(u"gineas", -1, 3),
        Among(u"ginis", -1, 3),
        Among(u"acht", -1, 1),
        Among(u"arcacht", 19, 2),
        Among(u"eacht", 19, 1),
        Among(u"grafa\u00EDocht", -1, 4),
        Among(u"arcachta\u00ED", -1, 2),
        Among(u"grafa\u00EDochta\u00ED", -1, 4)
    ]

    a_3 = [
        Among(u"imid", -1, 1),
        Among(u"aimid", 0, 1),
        Among(u"\u00EDmid", -1, 1),
        Among(u"a\u00EDmid", 2, 1),
        Among(u"adh", -1, 2),
        Among(u"eadh", 4, 2),
        Among(u"faidh", -1, 1),
        Among(u"fidh", -1, 1),
        Among(u"\u00E1il", -1, 2),
        Among(u"ain", -1, 2),
        Among(u"tear", -1, 2),
        Among(u"tar", -1, 2)
    ]

    g_v = [17, 65, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 17, 4, 2]

    I_p2 = 0
    I_p1 = 0
    I_pV = 0


    def __r_mark_regions(self):
        # (, line 28
        self.I_pV = self.limit
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        # do, line 34
        v_1 = self.cursor
        try:
            # (, line 34
            # gopast, line 35
            try:
                while True:
                    try:
                        if not self.in_grouping(IrishStemmer.g_v, 97, 250):
                            raise lab2()
                        raise lab1()
                    except lab2: pass
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
            except lab1: pass
            # setmark pV, line 35
            self.I_pV = self.cursor
        except lab0: pass
        self.cursor = v_1
        # do, line 37
        v_3 = self.cursor
        try:
            # (, line 37
            # gopast, line 38
            try:
                while True:
                    try:
                        if not self.in_grouping(IrishStemmer.g_v, 97, 250):
                            raise lab5()
                        raise lab4()
                    except lab5: pass
                    if self.cursor >= self.limit:
                        raise lab3()
                    self.cursor += 1
            except lab4: pass
            # gopast, line 38
            try:
                while True:
                    try:
                        if not self.out_grouping(IrishStemmer.g_v, 97, 250):
                            raise lab7()
                        raise lab6()
                    except lab7: pass
                    if self.cursor >= self.limit:
                        raise lab3()
                    self.cursor += 1
            except lab6: pass
            # setmark p1, line 38
            self.I_p1 = self.cursor
            # gopast, line 39
            try:
                while True:
                    try:
                        if not self.in_grouping(IrishStemmer.g_v, 97, 250):
                            raise lab9()
                        raise lab8()
                    except lab9: pass
                    if self.cursor >= self.limit:
                        raise lab3()
                    self.cursor += 1
            except lab8: pass
            # gopast, line 39
            try:
                while True:
                    try:
                        if not self.out_grouping(IrishStemmer.g_v, 97, 250):
                            raise lab11()
                        raise lab10()
                    except lab11: pass
                    if self.cursor >= self.limit:
                        raise lab3()
                    self.cursor += 1
            except lab10: pass
            # setmark p2, line 39
            self.I_p2 = self.cursor
        except lab3: pass
        self.cursor = v_3
        return True

    def __r_initial_morph(self):
        # (, line 43
        # [, line 44
        self.bra = self.cursor
        # substring, line 44
        among_var = self.find_among(IrishStemmer.a_0)
        if among_var == 0:
            return False
        # ], line 44
        self.ket = self.cursor
        if among_var == 1:
            # (, line 46
            # delete, line 46
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 52
            # <-, line 52
            if not self.slice_from(u"f"):
                return False
        elif among_var == 3:
            # (, line 58
            # <-, line 58
            if not self.slice_from(u"s"):
                return False
        elif among_var == 4:
            # (, line 61
            # <-, line 61
            if not self.slice_from(u"b"):
                return False
        elif among_var == 5:
            # (, line 63
            # <-, line 63
            if not self.slice_from(u"c"):
                return False
        elif among_var == 6:
            # (, line 65
            # <-, line 65
            if not self.slice_from(u"d"):
                return False
        elif among_var == 7:
            # (, line 69
            # <-, line 69
            if not self.slice_from(u"g"):
                return False
        elif among_var == 8:
            # (, line 71
            # <-, line 71
            if not self.slice_from(u"p"):
                return False
        elif among_var == 9:
            # (, line 75
            # <-, line 75
            if not self.slice_from(u"t"):
                return False
        elif among_var == 10:
            # (, line 89
            # <-, line 89
            if not self.slice_from(u"m"):
                return False
        return True

    def __r_RV(self):
        if not self.I_pV <= self.cursor:
            return False
        return True

    def __r_R1(self):
        if not self.I_p1 <= self.cursor:
            return False
        return True

    def __r_R2(self):
        if not self.I_p2 <= self.cursor:
            return False
        return True

    def __r_noun_sfx(self):
        # (, line 103
        # [, line 104
        self.ket = self.cursor
        # substring, line 104
        among_var = self.find_among_b(IrishStemmer.a_1)
        if among_var == 0:
            return False
        # ], line 104
        self.bra = self.cursor
        if among_var == 1:
            # (, line 108
            # call R1, line 108
            if not self.__r_R1():
                return False
            # delete, line 108
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 110
            # call R2, line 110
            if not self.__r_R2():
                return False
            # delete, line 110
            if not self.slice_del():
                return False

        return True

    def __r_deriv(self):
        # (, line 113
        # [, line 114
        self.ket = self.cursor
        # substring, line 114
        among_var = self.find_among_b(IrishStemmer.a_2)
        if among_var == 0:
            return False
        # ], line 114
        self.bra = self.cursor
        if among_var == 1:
            # (, line 116
            # call R2, line 116
            if not self.__r_R2():
                return False
            # delete, line 116
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 118
            # <-, line 118
            if not self.slice_from(u"arc"):
                return False
        elif among_var == 3:
            # (, line 120
            # <-, line 120
            if not self.slice_from(u"gin"):
                return False
        elif among_var == 4:
            # (, line 122
            # <-, line 122
            if not self.slice_from(u"graf"):
                return False
        elif among_var == 5:
            # (, line 124
            # <-, line 124
            if not self.slice_from(u"paite"):
                return False
        elif among_var == 6:
            # (, line 126
            # <-, line 126
            if not self.slice_from(u"\u00F3id"):
                return False
        return True

    def __r_verb_sfx(self):
        # (, line 129
        # [, line 130
        self.ket = self.cursor
        # substring, line 130
        among_var = self.find_among_b(IrishStemmer.a_3)
        if among_var == 0:
            return False
        # ], line 130
        self.bra = self.cursor
        if among_var == 1:
            # (, line 133
            # call RV, line 133
            if not self.__r_RV():
                return False
            # delete, line 133
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 138
            # call R1, line 138
            if not self.__r_R1():
                return False
            # delete, line 138
            if not self.slice_del():
                return False

        return True

    def _stem(self):
        # (, line 143
        # do, line 144
        v_1 = self.cursor
        # call initial_morph, line 144
        self.__r_initial_morph()
        self.cursor = v_1
        # do, line 145
        # call mark_regions, line 145
        self.__r_mark_regions()
        # backwards, line 146
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # (, line 146
        # do, line 147
        v_3 = self.limit - self.cursor
        # call noun_sfx, line 147
        self.__r_noun_sfx()
        self.cursor = self.limit - v_3
        # do, line 148
        v_4 = self.limit - self.cursor
        # call deriv, line 148
        self.__r_deriv()
        self.cursor = self.limit - v_4
        # do, line 149
        v_5 = self.limit - self.cursor
        # call verb_sfx, line 149
        self.__r_verb_sfx()
        self.cursor = self.limit - v_5
        self.cursor = self.limit_backward
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass


class lab5(BaseException): pass


class lab6(BaseException): pass


class lab7(BaseException): pass


class lab8(BaseException): pass


class lab9(BaseException): pass


class lab10(BaseException): pass


class lab11(BaseException): pass



# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class NepaliStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"\u0932\u093E\u0907", -1, 1),
        Among(u"\u0932\u093E\u0908", -1, 1),
        Among(u"\u0938\u0901\u0917", -1, 1),
        Among(u"\u0938\u0902\u0917", -1, 1),
        Among(u"\u092E\u093E\u0930\u094D\u092B\u0924", -1, 1),
        Among(u"\u0930\u0924", -1, 1),
        Among(u"\u0915\u093E", -1, 2),
        Among(u"\u092E\u093E", -1, 1),
        Among(u"\u0926\u094D\u0935\u093E\u0930\u093E", -1, 1),
        Among(u"\u0915\u093F", -1, 2),
        Among(u"\u092A\u091B\u093F", -1, 1),
        Among(u"\u0915\u0940", -1, 2),
        Among(u"\u0932\u0947", -1, 1),
        Among(u"\u0915\u0948", -1, 2),
        Among(u"\u0938\u0901\u0917\u0948", -1, 1),
        Among(u"\u092E\u0948", -1, 1),
        Among(u"\u0915\u094B", -1, 2)
    ]

    a_1 = [
        Among(u"\u0901", -1, -1),
        Among(u"\u0902", -1, -1),
        Among(u"\u0948", -1, -1)
    ]

    a_2 = [
        Among(u"\u0901", -1, 1),
        Among(u"\u0902", -1, 1),
        Among(u"\u0948", -1, 2)
    ]

    a_3 = [
        Among(u"\u0925\u093F\u090F", -1, 1),
        Among(u"\u091B", -1, 1),
        Among(u"\u0907\u091B", 1, 1),
        Among(u"\u090F\u091B", 1, 1),
        Among(u"\u093F\u091B", 1, 1),
        Among(u"\u0947\u091B", 1, 1),
        Among(u"\u0928\u0947\u091B", 5, 1),
        Among(u"\u0939\u0941\u0928\u0947\u091B", 6, 1),
        Among(u"\u0907\u0928\u094D\u091B", 1, 1),
        Among(u"\u093F\u0928\u094D\u091B", 1, 1),
        Among(u"\u0939\u0941\u0928\u094D\u091B", 1, 1),
        Among(u"\u090F\u0915\u093E", -1, 1),
        Among(u"\u0907\u090F\u0915\u093E", 11, 1),
        Among(u"\u093F\u090F\u0915\u093E", 11, 1),
        Among(u"\u0947\u0915\u093E", -1, 1),
        Among(u"\u0928\u0947\u0915\u093E", 14, 1),
        Among(u"\u0926\u093E", -1, 1),
        Among(u"\u0907\u0926\u093E", 16, 1),
        Among(u"\u093F\u0926\u093E", 16, 1),
        Among(u"\u0926\u0947\u0916\u093F", -1, 1),
        Among(u"\u092E\u093E\u0925\u093F", -1, 1),
        Among(u"\u090F\u0915\u0940", -1, 1),
        Among(u"\u0907\u090F\u0915\u0940", 21, 1),
        Among(u"\u093F\u090F\u0915\u0940", 21, 1),
        Among(u"\u0947\u0915\u0940", -1, 1),
        Among(u"\u0926\u0947\u0916\u0940", -1, 1),
        Among(u"\u0925\u0940", -1, 1),
        Among(u"\u0926\u0940", -1, 1),
        Among(u"\u091B\u0941", -1, 1),
        Among(u"\u090F\u091B\u0941", 28, 1),
        Among(u"\u0947\u091B\u0941", 28, 1),
        Among(u"\u0928\u0947\u091B\u0941", 30, 1),
        Among(u"\u0928\u0941", -1, 1),
        Among(u"\u0939\u0930\u0941", -1, 1),
        Among(u"\u0939\u0930\u0942", -1, 1),
        Among(u"\u091B\u0947", -1, 1),
        Among(u"\u0925\u0947", -1, 1),
        Among(u"\u0928\u0947", -1, 1),
        Among(u"\u090F\u0915\u0948", -1, 1),
        Among(u"\u0947\u0915\u0948", -1, 1),
        Among(u"\u0928\u0947\u0915\u0948", 39, 1),
        Among(u"\u0926\u0948", -1, 1),
        Among(u"\u0907\u0926\u0948", 41, 1),
        Among(u"\u093F\u0926\u0948", 41, 1),
        Among(u"\u090F\u0915\u094B", -1, 1),
        Among(u"\u0907\u090F\u0915\u094B", 44, 1),
        Among(u"\u093F\u090F\u0915\u094B", 44, 1),
        Among(u"\u0947\u0915\u094B", -1, 1),
        Among(u"\u0928\u0947\u0915\u094B", 47, 1),
        Among(u"\u0926\u094B", -1, 1),
        Among(u"\u0907\u0926\u094B", 49, 1),
        Among(u"\u093F\u0926\u094B", 49, 1),
        Among(u"\u092F\u094B", -1, 1),
        Among(u"\u0907\u092F\u094B", 52, 1),
        Among(u"\u092D\u092F\u094B", 52, 1),
        Among(u"\u093F\u092F\u094B", 52, 1),
        Among(u"\u0925\u093F\u092F\u094B", 55, 1),
        Among(u"\u0926\u093F\u092F\u094B", 55, 1),
        Among(u"\u0925\u094D\u092F\u094B", 52, 1),
        Among(u"\u091B\u094C", -1, 1),
        Among(u"\u0907\u091B\u094C", 59, 1),
        Among(u"\u090F\u091B\u094C", 59, 1),
        Among(u"\u093F\u091B\u094C", 59, 1),
        Among(u"\u0947\u091B\u094C", 59, 1),
        Among(u"\u0928\u0947\u091B\u094C", 63, 1),
        Among(u"\u092F\u094C", -1, 1),
        Among(u"\u0925\u093F\u092F\u094C", 65, 1),
        Among(u"\u091B\u094D\u092F\u094C", 65, 1),
        Among(u"\u0925\u094D\u092F\u094C", 65, 1),
        Among(u"\u091B\u0928\u094D", -1, 1),
        Among(u"\u0907\u091B\u0928\u094D", 69, 1),
        Among(u"\u090F\u091B\u0928\u094D", 69, 1),
        Among(u"\u093F\u091B\u0928\u094D", 69, 1),
        Among(u"\u0947\u091B\u0928\u094D", 69, 1),
        Among(u"\u0928\u0947\u091B\u0928\u094D", 73, 1),
        Among(u"\u0932\u093E\u0928\u094D", -1, 1),
        Among(u"\u091B\u093F\u0928\u094D", -1, 1),
        Among(u"\u0925\u093F\u0928\u094D", -1, 1),
        Among(u"\u092A\u0930\u094D", -1, 1),
        Among(u"\u0907\u0938\u094D", -1, 1),
        Among(u"\u0925\u093F\u0907\u0938\u094D", 79, 1),
        Among(u"\u091B\u0938\u094D", -1, 1),
        Among(u"\u0907\u091B\u0938\u094D", 81, 1),
        Among(u"\u090F\u091B\u0938\u094D", 81, 1),
        Among(u"\u093F\u091B\u0938\u094D", 81, 1),
        Among(u"\u0947\u091B\u0938\u094D", 81, 1),
        Among(u"\u0928\u0947\u091B\u0938\u094D", 85, 1),
        Among(u"\u093F\u0938\u094D", -1, 1),
        Among(u"\u0925\u093F\u0938\u094D", 87, 1),
        Among(u"\u091B\u0947\u0938\u094D", -1, 1),
        Among(u"\u0939\u094B\u0938\u094D", -1, 1)
    ]



    def __r_remove_category_1(self):
        # (, line 53
        # [, line 54
        self.ket = self.cursor
        # substring, line 54
        among_var = self.find_among_b(NepaliStemmer.a_0)
        if among_var == 0:
            return False
        # ], line 54
        self.bra = self.cursor
        if among_var == 1:
            # (, line 58
            # delete, line 58
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 59
            # or, line 59
            try:
                v_1 = self.limit - self.cursor
                try:
                    # (, line 59
                    # or, line 59
                    try:
                        v_2 = self.limit - self.cursor
                        try:
                            # literal, line 59
                            if not self.eq_s_b(u"\u090F"):
                                raise lab3()
                            raise lab2()
                        except lab3: pass
                        self.cursor = self.limit - v_2
                        # literal, line 59
                        if not self.eq_s_b(u"\u0947"):
                            raise lab1()
                    except lab2: pass
                    # (, line 59
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_1
                # delete, line 59
                if not self.slice_del():
                    return False

            except lab0: pass
        return True

    def __r_check_category_2(self):
        # (, line 63
        # [, line 64
        self.ket = self.cursor
        # substring, line 64
        if self.find_among_b(NepaliStemmer.a_1) == 0:
            return False
        # ], line 64
        self.bra = self.cursor
        return True

    def __r_remove_category_2(self):
        # (, line 69
        # [, line 70
        self.ket = self.cursor
        # substring, line 70
        among_var = self.find_among_b(NepaliStemmer.a_2)
        if among_var == 0:
            return False
        # ], line 70
        self.bra = self.cursor
        if among_var == 1:
            # (, line 71
            # or, line 71
            try:
                v_1 = self.limit - self.cursor
                try:
                    # literal, line 71
                    if not self.eq_s_b(u"\u092F\u094C"):
                        raise lab1()
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_1
                try:
                    # literal, line 71
                    if not self.eq_s_b(u"\u091B\u094C"):
                        raise lab2()
                    raise lab0()
                except lab2: pass
                self.cursor = self.limit - v_1
                try:
                    # literal, line 71
                    if not self.eq_s_b(u"\u0928\u094C"):
                        raise lab3()
                    raise lab0()
                except lab3: pass
                self.cursor = self.limit - v_1
                # literal, line 71
                if not self.eq_s_b(u"\u0925\u0947"):
                    return False
            except lab0: pass
            # delete, line 71
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 72
            # literal, line 72
            if not self.eq_s_b(u"\u0924\u094D\u0930"):
                return False
            # delete, line 72
            if not self.slice_del():
                return False

        return True

    def __r_remove_category_3(self):
        # (, line 76
        # [, line 77
        self.ket = self.cursor
        # substring, line 77
        if self.find_among_b(NepaliStemmer.a_3) == 0:
            return False
        # ], line 77
        self.bra = self.cursor
        # (, line 79
        # delete, line 79
        if not self.slice_del():
            return False

        return True

    def _stem(self):
        # (, line 85
        # backwards, line 86
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # (, line 86
        # do, line 87
        v_1 = self.limit - self.cursor
        # call remove_category_1, line 87
        self.__r_remove_category_1()
        self.cursor = self.limit - v_1
        # do, line 88
        v_2 = self.limit - self.cursor
        try:
            # (, line 88
            # repeat, line 89
            try:
                while True:
                    try:
                        v_3 = self.limit - self.cursor
                        try:
                            # (, line 89
                            # do, line 89
                            v_4 = self.limit - self.cursor
                            try:
                                # (, line 89
                                # and, line 89
                                v_5 = self.limit - self.cursor
                                # call check_category_2, line 89
                                if not self.__r_check_category_2():
                                    raise lab4()
                                self.cursor = self.limit - v_5
                                # call remove_category_2, line 89
                                if not self.__r_remove_category_2():
                                    raise lab4()
                            except lab4: pass
                            self.cursor = self.limit - v_4
                            # call remove_category_3, line 89
                            if not self.__r_remove_category_3():
                                raise lab3()
                            raise lab2()
                        except lab3: pass
                        self.cursor = self.limit - v_3
                        raise lab1()
                    except lab2: pass
            except lab1: pass
        except lab0: pass
        self.cursor = self.limit - v_2
        self.cursor = self.limit_backward
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass



# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class DutchStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"", -1, 6),
        Among(u"\u00E1", 0, 1),
        Among(u"\u00E4", 0, 1),
        Among(u"\u00E9", 0, 2),
        Among(u"\u00EB", 0, 2),
        Among(u"\u00ED", 0, 3),
        Among(u"\u00EF", 0, 3),
        Among(u"\u00F3", 0, 4),
        Among(u"\u00F6", 0, 4),
        Among(u"\u00FA", 0, 5),
        Among(u"\u00FC", 0, 5)
    ]

    a_1 = [
        Among(u"", -1, 3),
        Among(u"I", 0, 2),
        Among(u"Y", 0, 1)
    ]

    a_2 = [
        Among(u"dd", -1, -1),
        Among(u"kk", -1, -1),
        Among(u"tt", -1, -1)
    ]

    a_3 = [
        Among(u"ene", -1, 2),
        Among(u"se", -1, 3),
        Among(u"en", -1, 2),
        Among(u"heden", 2, 1),
        Among(u"s", -1, 3)
    ]

    a_4 = [
        Among(u"end", -1, 1),
        Among(u"ig", -1, 2),
        Among(u"ing", -1, 1),
        Among(u"lijk", -1, 3),
        Among(u"baar", -1, 4),
        Among(u"bar", -1, 5)
    ]

    a_5 = [
        Among(u"aa", -1, -1),
        Among(u"ee", -1, -1),
        Among(u"oo", -1, -1),
        Among(u"uu", -1, -1)
    ]

    g_v = [17, 65, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128]

    g_v_I = [1, 0, 0, 17, 65, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128]

    g_v_j = [17, 67, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128]

    I_p2 = 0
    I_p1 = 0
    B_e_found = False


    def __r_prelude(self):
        # (, line 41
        # test, line 42
        v_1 = self.cursor
        # repeat, line 42
        try:
            while True:
                try:
                    v_2 = self.cursor
                    try:
                        # (, line 42
                        # [, line 43
                        self.bra = self.cursor
                        # substring, line 43
                        among_var = self.find_among(DutchStemmer.a_0)
                        if among_var == 0:
                            raise lab2()
                        # ], line 43
                        self.ket = self.cursor
                        if among_var == 1:
                            # (, line 45
                            # <-, line 45
                            if not self.slice_from(u"a"):
                                return False
                        elif among_var == 2:
                            # (, line 47
                            # <-, line 47
                            if not self.slice_from(u"e"):
                                return False
                        elif among_var == 3:
                            # (, line 49
                            # <-, line 49
                            if not self.slice_from(u"i"):
                                return False
                        elif among_var == 4:
                            # (, line 51
                            # <-, line 51
                            if not self.slice_from(u"o"):
                                return False
                        elif among_var == 5:
                            # (, line 53
                            # <-, line 53
                            if not self.slice_from(u"u"):
                                return False
                        elif among_var == 6:
                            # (, line 54
                            # next, line 54
                            if self.cursor >= self.limit:
                                raise lab2()
                            self.cursor += 1
                        raise lab1()
                    except lab2: pass
                    self.cursor = v_2
                    raise lab0()
                except lab1: pass
        except lab0: pass
        self.cursor = v_1
        # try, line 57
        v_3 = self.cursor
        try:
            # (, line 57
            # [, line 57
            self.bra = self.cursor
            # literal, line 57
            if not self.eq_s(u"y"):
                self.cursor = v_3
                raise lab3()
            # ], line 57
            self.ket = self.cursor
            # <-, line 57
            if not self.slice_from(u"Y"):
                return False
        except lab3: pass
        # repeat, line 58
        try:
            while True:
                try:
                    v_4 = self.cursor
                    try:
                        # goto, line 58
                        try:
                            while True:
                                v_5 = self.cursor
                                try:
                                    # (, line 58
                                    if not self.in_grouping(DutchStemmer.g_v, 97, 232):
                                        raise lab8()
                                    # [, line 59
                                    self.bra = self.cursor
                                    # or, line 59
                                    try:
                                        v_6 = self.cursor
                                        try:
                                            # (, line 59
                                            # literal, line 59
                                            if not self.eq_s(u"i"):
                                                raise lab10()
                                            # ], line 59
                                            self.ket = self.cursor
                                            if not self.in_grouping(DutchStemmer.g_v, 97, 232):
                                                raise lab10()
                                            # <-, line 59
                                            if not self.slice_from(u"I"):
                                                return False
                                            raise lab9()
                                        except lab10: pass
                                        self.cursor = v_6
                                        # (, line 60
                                        # literal, line 60
                                        if not self.eq_s(u"y"):
                                            raise lab8()
                                        # ], line 60
                                        self.ket = self.cursor
                                        # <-, line 60
                                        if not self.slice_from(u"Y"):
                                            return False
                                    except lab9: pass
                                    self.cursor = v_5
                                    raise lab7()
                                except lab8: pass
                                self.cursor = v_5
                                if self.cursor >= self.limit:
                                    raise lab6()
                                self.cursor += 1
                        except lab7: pass
                        raise lab5()
                    except lab6: pass
                    self.cursor = v_4
                    raise lab4()
                except lab5: pass
        except lab4: pass
        return True

    def __r_mark_regions(self):
        # (, line 64
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        # gopast, line 69
        try:
            while True:
                try:
                    if not self.in_grouping(DutchStemmer.g_v, 97, 232):
                        raise lab1()
                    raise lab0()
                except lab1: pass
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab0: pass
        # gopast, line 69
        try:
            while True:
                try:
                    if not self.out_grouping(DutchStemmer.g_v, 97, 232):
                        raise lab3()
                    raise lab2()
                except lab3: pass
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab2: pass
        # setmark p1, line 69
        self.I_p1 = self.cursor
        # try, line 70
        try:
            # (, line 70
            if not self.I_p1 < 3:
                raise lab4()
            self.I_p1 = 3
        except lab4: pass
        # gopast, line 71
        try:
            while True:
                try:
                    if not self.in_grouping(DutchStemmer.g_v, 97, 232):
                        raise lab6()
                    raise lab5()
                except lab6: pass
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab5: pass
        # gopast, line 71
        try:
            while True:
                try:
                    if not self.out_grouping(DutchStemmer.g_v, 97, 232):
                        raise lab8()
                    raise lab7()
                except lab8: pass
                if self.cursor >= self.limit:
                    return False
                self.cursor += 1
        except lab7: pass
        # setmark p2, line 71
        self.I_p2 = self.cursor
        return True

    def __r_postlude(self):
        # repeat, line 75
        try:
            while True:
                try:
                    v_1 = self.cursor
                    try:
                        # (, line 75
                        # [, line 77
                        self.bra = self.cursor
                        # substring, line 77
                        among_var = self.find_among(DutchStemmer.a_1)
                        if among_var == 0:
                            raise lab2()
                        # ], line 77
                        self.ket = self.cursor
                        if among_var == 1:
                            # (, line 78
                            # <-, line 78
                            if not self.slice_from(u"y"):
                                return False
                        elif among_var == 2:
                            # (, line 79
                            # <-, line 79
                            if not self.slice_from(u"i"):
                                return False
                        elif among_var == 3:
                            # (, line 80
                            # next, line 80
                            if self.cursor >= self.limit:
                                raise lab2()
                            self.cursor += 1
                        raise lab1()
                    except lab2: pass
                    self.cursor = v_1
                    raise lab0()
                except lab1: pass
        except lab0: pass
        return True

    def __r_R1(self):
        if not self.I_p1 <= self.cursor:
            return False
        return True

    def __r_R2(self):
        if not self.I_p2 <= self.cursor:
            return False
        return True

    def __r_undouble(self):
        # (, line 90
        # test, line 91
        v_1 = self.limit - self.cursor
        # among, line 91
        if self.find_among_b(DutchStemmer.a_2) == 0:
            return False
        self.cursor = self.limit - v_1
        # [, line 91
        self.ket = self.cursor
        # next, line 91
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        # ], line 91
        self.bra = self.cursor
        # delete, line 91
        if not self.slice_del():
            return False

        return True

    def __r_e_ending(self):
        # (, line 94
        # unset e_found, line 95
        self.B_e_found = False
        # [, line 96
        self.ket = self.cursor
        # literal, line 96
        if not self.eq_s_b(u"e"):
            return False
        # ], line 96
        self.bra = self.cursor
        # call R1, line 96
        if not self.__r_R1():
            return False
        # test, line 96
        v_1 = self.limit - self.cursor
        if not self.out_grouping_b(DutchStemmer.g_v, 97, 232):
            return False
        self.cursor = self.limit - v_1
        # delete, line 96
        if not self.slice_del():
            return False

        # set e_found, line 97
        self.B_e_found = True
        # call undouble, line 98
        if not self.__r_undouble():
            return False
        return True

    def __r_en_ending(self):
        # (, line 101
        # call R1, line 102
        if not self.__r_R1():
            return False
        # and, line 102
        v_1 = self.limit - self.cursor
        if not self.out_grouping_b(DutchStemmer.g_v, 97, 232):
            return False
        self.cursor = self.limit - v_1
        # not, line 102
        v_2 = self.limit - self.cursor
        try:
            # literal, line 102
            if not self.eq_s_b(u"gem"):
                raise lab0()
            return False
        except lab0: pass
        self.cursor = self.limit - v_2
        # delete, line 102
        if not self.slice_del():
            return False

        # call undouble, line 103
        if not self.__r_undouble():
            return False
        return True

    def __r_standard_suffix(self):
        # (, line 106
        # do, line 107
        v_1 = self.limit - self.cursor
        try:
            # (, line 107
            # [, line 108
            self.ket = self.cursor
            # substring, line 108
            among_var = self.find_among_b(DutchStemmer.a_3)
            if among_var == 0:
                raise lab0()
            # ], line 108
            self.bra = self.cursor
            if among_var == 1:
                # (, line 110
                # call R1, line 110
                if not self.__r_R1():
                    raise lab0()
                # <-, line 110
                if not self.slice_from(u"heid"):
                    return False
            elif among_var == 2:
                # (, line 113
                # call en_ending, line 113
                if not self.__r_en_ending():
                    raise lab0()
            elif among_var == 3:
                # (, line 116
                # call R1, line 116
                if not self.__r_R1():
                    raise lab0()
                if not self.out_grouping_b(DutchStemmer.g_v_j, 97, 232):
                    raise lab0()
                # delete, line 116
                if not self.slice_del():
                    return False

        except lab0: pass
        self.cursor = self.limit - v_1
        # do, line 120
        v_2 = self.limit - self.cursor
        # call e_ending, line 120
        self.__r_e_ending()
        self.cursor = self.limit - v_2
        # do, line 122
        v_3 = self.limit - self.cursor
        try:
            # (, line 122
            # [, line 122
            self.ket = self.cursor
            # literal, line 122
            if not self.eq_s_b(u"heid"):
                raise lab1()
            # ], line 122
            self.bra = self.cursor
            # call R2, line 122
            if not self.__r_R2():
                raise lab1()
            # not, line 122
            v_4 = self.limit - self.cursor
            try:
                # literal, line 122
                if not self.eq_s_b(u"c"):
                    raise lab2()
                raise lab1()
            except lab2: pass
            self.cursor = self.limit - v_4
            # delete, line 122
            if not self.slice_del():
                return False

            # [, line 123
            self.ket = self.cursor
            # literal, line 123
            if not self.eq_s_b(u"en"):
                raise lab1()
            # ], line 123
            self.bra = self.cursor
            # call en_ending, line 123
            if not self.__r_en_ending():
                raise lab1()
        except lab1: pass
        self.cursor = self.limit - v_3
        # do, line 126
        v_5 = self.limit - self.cursor
        try:
            # (, line 126
            # [, line 127
            self.ket = self.cursor
            # substring, line 127
            among_var = self.find_among_b(DutchStemmer.a_4)
            if among_var == 0:
                raise lab3()
            # ], line 127
            self.bra = self.cursor
            if among_var == 1:
                # (, line 129
                # call R2, line 129
                if not self.__r_R2():
                    raise lab3()
                # delete, line 129
                if not self.slice_del():
                    return False

                # or, line 130
                try:
                    v_6 = self.limit - self.cursor
                    try:
                        # (, line 130
                        # [, line 130
                        self.ket = self.cursor
                        # literal, line 130
                        if not self.eq_s_b(u"ig"):
                            raise lab5()
                        # ], line 130
                        self.bra = self.cursor
                        # call R2, line 130
                        if not self.__r_R2():
                            raise lab5()
                        # not, line 130
                        v_7 = self.limit - self.cursor
                        try:
                            # literal, line 130
                            if not self.eq_s_b(u"e"):
                                raise lab6()
                            raise lab5()
                        except lab6: pass
                        self.cursor = self.limit - v_7
                        # delete, line 130
                        if not self.slice_del():
                            return False

                        raise lab4()
                    except lab5: pass
                    self.cursor = self.limit - v_6
                    # call undouble, line 130
                    if not self.__r_undouble():
                        raise lab3()
                except lab4: pass
            elif among_var == 2:
                # (, line 133
                # call R2, line 133
                if not self.__r_R2():
                    raise lab3()
                # not, line 133
                v_8 = self.limit - self.cursor
                try:
                    # literal, line 133
                    if not self.eq_s_b(u"e"):
                        raise lab7()
                    raise lab3()
                except lab7: pass
                self.cursor = self.limit - v_8
                # delete, line 133
                if not self.slice_del():
                    return False

            elif among_var == 3:
                # (, line 136
                # call R2, line 136
                if not self.__r_R2():
                    raise lab3()
                # delete, line 136
                if not self.slice_del():
                    return False

                # call e_ending, line 136
                if not self.__r_e_ending():
                    raise lab3()
            elif among_var == 4:
                # (, line 139
                # call R2, line 139
                if not self.__r_R2():
                    raise lab3()
                # delete, line 139
                if not self.slice_del():
                    return False

            elif among_var == 5:
                # (, line 142
                # call R2, line 142
                if not self.__r_R2():
                    raise lab3()
                # Boolean test e_found, line 142
                if not self.B_e_found:
                    raise lab3()
                # delete, line 142
                if not self.slice_del():
                    return False

        except lab3: pass
        self.cursor = self.limit - v_5
        # do, line 146
        v_9 = self.limit - self.cursor
        try:
            # (, line 146
            if not self.out_grouping_b(DutchStemmer.g_v_I, 73, 232):
                raise lab8()
            # test, line 148
            v_10 = self.limit - self.cursor
            # (, line 148
            # among, line 149
            if self.find_among_b(DutchStemmer.a_5) == 0:
                raise lab8()
            if not self.out_grouping_b(DutchStemmer.g_v, 97, 232):
                raise lab8()
            self.cursor = self.limit - v_10
            # [, line 152
            self.ket = self.cursor
            # next, line 152
            if self.cursor <= self.limit_backward:
                raise lab8()
            self.cursor -= 1
            # ], line 152
            self.bra = self.cursor
            # delete, line 152
            if not self.slice_del():
                return False

        except lab8: pass
        self.cursor = self.limit - v_9
        return True

    def _stem(self):
        # (, line 157
        # do, line 159
        v_1 = self.cursor
        # call prelude, line 159
        self.__r_prelude()
        self.cursor = v_1
        # do, line 160
        v_2 = self.cursor
        # call mark_regions, line 160
        self.__r_mark_regions()
        self.cursor = v_2
        # backwards, line 161
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # do, line 162
        # call standard_suffix, line 162
        self.__r_standard_suffix()
        self.cursor = self.limit_backward
        # do, line 163
        v_4 = self.cursor
        # call postlude, line 163
        self.__r_postlude()
        self.cursor = v_4
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass


class lab5(BaseException): pass


class lab6(BaseException): pass


class lab7(BaseException): pass


class lab8(BaseException): pass


class lab9(BaseException): pass


class lab10(BaseException): pass



# This file was generated automatically by the Snowball to Python compiler
# http://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class FrenchStemmer(BaseStemmer):
    '''
    This class was automatically generated by a Snowball to Python compiler
    It implements the stemming algorithm defined by a snowball script.
    '''

    a_0 = [
        Among(u"col", -1, -1),
        Among(u"par", -1, -1),
        Among(u"tap", -1, -1)
    ]

    a_1 = [
        Among(u"", -1, 7),
        Among(u"H", 0, 6),
        Among(u"He", 1, 4),
        Among(u"Hi", 1, 5),
        Among(u"I", 0, 1),
        Among(u"U", 0, 2),
        Among(u"Y", 0, 3)
    ]

    a_2 = [
        Among(u"iqU", -1, 3),
        Among(u"abl", -1, 3),
        Among(u"I\u00E8r", -1, 4),
        Among(u"i\u00E8r", -1, 4),
        Among(u"eus", -1, 2),
        Among(u"iv", -1, 1)
    ]

    a_3 = [
        Among(u"ic", -1, 2),
        Among(u"abil", -1, 1),
        Among(u"iv", -1, 3)
    ]

    a_4 = [
        Among(u"iqUe", -1, 1),
        Among(u"atrice", -1, 2),
        Among(u"ance", -1, 1),
        Among(u"ence", -1, 5),
        Among(u"logie", -1, 3),
        Among(u"able", -1, 1),
        Among(u"isme", -1, 1),
        Among(u"euse", -1, 11),
        Among(u"iste", -1, 1),
        Among(u"ive", -1, 8),
        Among(u"if", -1, 8),
        Among(u"usion", -1, 4),
        Among(u"ation", -1, 2),
        Among(u"ution", -1, 4),
        Among(u"ateur", -1, 2),
        Among(u"iqUes", -1, 1),
        Among(u"atrices", -1, 2),
        Among(u"ances", -1, 1),
        Among(u"ences", -1, 5),
        Among(u"logies", -1, 3),
        Among(u"ables", -1, 1),
        Among(u"ismes", -1, 1),
        Among(u"euses", -1, 11),
        Among(u"istes", -1, 1),
        Among(u"ives", -1, 8),
        Among(u"ifs", -1, 8),
        Among(u"usions", -1, 4),
        Among(u"ations", -1, 2),
        Among(u"utions", -1, 4),
        Among(u"ateurs", -1, 2),
        Among(u"ments", -1, 15),
        Among(u"ements", 30, 6),
        Among(u"issements", 31, 12),
        Among(u"it\u00E9s", -1, 7),
        Among(u"ment", -1, 15),
        Among(u"ement", 34, 6),
        Among(u"issement", 35, 12),
        Among(u"amment", 34, 13),
        Among(u"emment", 34, 14),
        Among(u"aux", -1, 10),
        Among(u"eaux", 39, 9),
        Among(u"eux", -1, 1),
        Among(u"it\u00E9", -1, 7)
    ]

    a_5 = [
        Among(u"ira", -1, 1),
        Among(u"ie", -1, 1),
        Among(u"isse", -1, 1),
        Among(u"issante", -1, 1),
        Among(u"i", -1, 1),
        Among(u"irai", 4, 1),
        Among(u"ir", -1, 1),
        Among(u"iras", -1, 1),
        Among(u"ies", -1, 1),
        Among(u"\u00EEmes", -1, 1),
        Among(u"isses", -1, 1),
        Among(u"issantes", -1, 1),
        Among(u"\u00EEtes", -1, 1),
        Among(u"is", -1, 1),
        Among(u"irais", 13, 1),
        Among(u"issais", 13, 1),
        Among(u"irions", -1, 1),
        Among(u"issions", -1, 1),
        Among(u"irons", -1, 1),
        Among(u"issons", -1, 1),
        Among(u"issants", -1, 1),
        Among(u"it", -1, 1),
        Among(u"irait", 21, 1),
        Among(u"issait", 21, 1),
        Among(u"issant", -1, 1),
        Among(u"iraIent", -1, 1),
        Among(u"issaIent", -1, 1),
        Among(u"irent", -1, 1),
        Among(u"issent", -1, 1),
        Among(u"iront", -1, 1),
        Among(u"\u00EEt", -1, 1),
        Among(u"iriez", -1, 1),
        Among(u"issiez", -1, 1),
        Among(u"irez", -1, 1),
        Among(u"issez", -1, 1)
    ]

    a_6 = [
        Among(u"a", -1, 3),
        Among(u"era", 0, 2),
        Among(u"asse", -1, 3),
        Among(u"ante", -1, 3),
        Among(u"\u00E9e", -1, 2),
        Among(u"ai", -1, 3),
        Among(u"erai", 5, 2),
        Among(u"er", -1, 2),
        Among(u"as", -1, 3),
        Among(u"eras", 8, 2),
        Among(u"\u00E2mes", -1, 3),
        Among(u"asses", -1, 3),
        Among(u"antes", -1, 3),
        Among(u"\u00E2tes", -1, 3),
        Among(u"\u00E9es", -1, 2),
        Among(u"ais", -1, 3),
        Among(u"erais", 15, 2),
        Among(u"ions", -1, 1),
        Among(u"erions", 17, 2),
        Among(u"assions", 17, 3),
        Among(u"erons", -1, 2),
        Among(u"ants", -1, 3),
        Among(u"\u00E9s", -1, 2),
        Among(u"ait", -1, 3),
        Among(u"erait", 23, 2),
        Among(u"ant", -1, 3),
        Among(u"aIent", -1, 3),
        Among(u"eraIent", 26, 2),
        Among(u"\u00E8rent", -1, 2),
        Among(u"assent", -1, 3),
        Among(u"eront", -1, 2),
        Among(u"\u00E2t", -1, 3),
        Among(u"ez", -1, 2),
        Among(u"iez", 32, 2),
        Among(u"eriez", 33, 2),
        Among(u"assiez", 33, 3),
        Among(u"erez", 32, 2),
        Among(u"\u00E9", -1, 2)
    ]

    a_7 = [
        Among(u"e", -1, 3),
        Among(u"I\u00E8re", 0, 2),
        Among(u"i\u00E8re", 0, 2),
        Among(u"ion", -1, 1),
        Among(u"Ier", -1, 2),
        Among(u"ier", -1, 2)
    ]

    a_8 = [
        Among(u"ell", -1, -1),
        Among(u"eill", -1, -1),
        Among(u"enn", -1, -1),
        Among(u"onn", -1, -1),
        Among(u"ett", -1, -1)
    ]

    g_v = [17, 65, 16, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 130, 103, 8, 5]

    g_keep_with_s = [1, 65, 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128]

    I_p2 = 0
    I_p1 = 0
    I_pV = 0


    def __r_prelude(self):
        # repeat, line 38
        try:
            while True:
                try:
                    v_1 = self.cursor
                    try:
                        # goto, line 38
                        try:
                            while True:
                                v_2 = self.cursor
                                try:
                                    # (, line 38
                                    # or, line 44
                                    try:
                                        v_3 = self.cursor
                                        try:
                                            # (, line 40
                                            if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                                                raise lab6()
                                            # [, line 40
                                            self.bra = self.cursor
                                            # or, line 40
                                            try:
                                                v_4 = self.cursor
                                                try:
                                                    # (, line 40
                                                    # literal, line 40
                                                    if not self.eq_s(u"u"):
                                                        raise lab8()
                                                    # ], line 40
                                                    self.ket = self.cursor
                                                    if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                                                        raise lab8()
                                                    # <-, line 40
                                                    if not self.slice_from(u"U"):
                                                        return False
                                                    raise lab7()
                                                except lab8: pass
                                                self.cursor = v_4
                                                try:
                                                    # (, line 41
                                                    # literal, line 41
                                                    if not self.eq_s(u"i"):
                                                        raise lab9()
                                                    # ], line 41
                                                    self.ket = self.cursor
                                                    if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                                                        raise lab9()
                                                    # <-, line 41
                                                    if not self.slice_from(u"I"):
                                                        return False
                                                    raise lab7()
                                                except lab9: pass
                                                self.cursor = v_4
                                                # (, line 42
                                                # literal, line 42
                                                if not self.eq_s(u"y"):
                                                    raise lab6()
                                                # ], line 42
                                                self.ket = self.cursor
                                                # <-, line 42
                                                if not self.slice_from(u"Y"):
                                                    return False
                                            except lab7: pass
                                            raise lab5()
                                        except lab6: pass
                                        self.cursor = v_3
                                        try:
                                            # (, line 45
                                            # [, line 45
                                            self.bra = self.cursor
                                            # literal, line 45
                                            if not self.eq_s(u"\u00EB"):
                                                raise lab10()
                                            # ], line 45
                                            self.ket = self.cursor
                                            # <-, line 45
                                            if not self.slice_from(u"He"):
                                                return False
                                            raise lab5()
                                        except lab10: pass
                                        self.cursor = v_3
                                        try:
                                            # (, line 47
                                            # [, line 47
                                            self.bra = self.cursor
                                            # literal, line 47
                                            if not self.eq_s(u"\u00EF"):
                                                raise lab11()
                                            # ], line 47
                                            self.ket = self.cursor
                                            # <-, line 47
                                            if not self.slice_from(u"Hi"):
                                                return False
                                            raise lab5()
                                        except lab11: pass
                                        self.cursor = v_3
                                        try:
                                            # (, line 49
                                            # [, line 49
                                            self.bra = self.cursor
                                            # literal, line 49
                                            if not self.eq_s(u"y"):
                                                raise lab12()
                                            # ], line 49
                                            self.ket = self.cursor
                                            if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                                                raise lab12()
                                            # <-, line 49
                                            if not self.slice_from(u"Y"):
                                                return False
                                            raise lab5()
                                        except lab12: pass
                                        self.cursor = v_3
                                        # (, line 51
                                        # literal, line 51
                                        if not self.eq_s(u"q"):
                                            raise lab4()
                                        # [, line 51
                                        self.bra = self.cursor
                                        # literal, line 51
                                        if not self.eq_s(u"u"):
                                            raise lab4()
                                        # ], line 51
                                        self.ket = self.cursor
                                        # <-, line 51
                                        if not self.slice_from(u"U"):
                                            return False
                                    except lab5: pass
                                    self.cursor = v_2
                                    raise lab3()
                                except lab4: pass
                                self.cursor = v_2
                                if self.cursor >= self.limit:
                                    raise lab2()
                                self.cursor += 1
                        except lab3: pass
                        raise lab1()
                    except lab2: pass
                    self.cursor = v_1
                    raise lab0()
                except lab1: pass
        except lab0: pass
        return True

    def __r_mark_regions(self):
        # (, line 54
        self.I_pV = self.limit
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        # do, line 60
        v_1 = self.cursor
        try:
            # (, line 60
            # or, line 62
            try:
                v_2 = self.cursor
                try:
                    # (, line 61
                    if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                        raise lab2()
                    if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                        raise lab2()
                    # next, line 61
                    if self.cursor >= self.limit:
                        raise lab2()
                    self.cursor += 1
                    raise lab1()
                except lab2: pass
                self.cursor = v_2
                try:
                    # among, line 63
                    if self.find_among(FrenchStemmer.a_0) == 0:
                        raise lab3()
                    raise lab1()
                except lab3: pass
                self.cursor = v_2
                # (, line 70
                # next, line 70
                if self.cursor >= self.limit:
                    raise lab0()
                self.cursor += 1
                # gopast, line 70
                try:
                    while True:
                        try:
                            if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                                raise lab5()
                            raise lab4()
                        except lab5: pass
                        if self.cursor >= self.limit:
                            raise lab0()
                        self.cursor += 1
                except lab4: pass
            except lab1: pass
            # setmark pV, line 71
            self.I_pV = self.cursor
        except lab0: pass
        self.cursor = v_1
        # do, line 73
        v_4 = self.cursor
        try:
            # (, line 73
            # gopast, line 74
            try:
                while True:
                    try:
                        if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                            raise lab8()
                        raise lab7()
                    except lab8: pass
                    if self.cursor >= self.limit:
                        raise lab6()
                    self.cursor += 1
            except lab7: pass
            # gopast, line 74
            try:
                while True:
                    try:
                        if not self.out_grouping(FrenchStemmer.g_v, 97, 251):
                            raise lab10()
                        raise lab9()
                    except lab10: pass
                    if self.cursor >= self.limit:
                        raise lab6()
                    self.cursor += 1
            except lab9: pass
            # setmark p1, line 74
            self.I_p1 = self.cursor
            # gopast, line 75
            try:
                while True:
                    try:
                        if not self.in_grouping(FrenchStemmer.g_v, 97, 251):
                            raise lab12()
                        raise lab11()
                    except lab12: pass
                    if self.cursor >= self.limit:
                        raise lab6()
                    self.cursor += 1
            except lab11: pass
            # gopast, line 75
            try:
                while True:
                    try:
                        if not self.out_grouping(FrenchStemmer.g_v, 97, 251):
                            raise lab14()
                        raise lab13()
                    except lab14: pass
                    if self.cursor >= self.limit:
                        raise lab6()
                    self.cursor += 1
            except lab13: pass
            # setmark p2, line 75
            self.I_p2 = self.cursor
        except lab6: pass
        self.cursor = v_4
        return True

    def __r_postlude(self):
        # repeat, line 79
        try:
            while True:
                try:
                    v_1 = self.cursor
                    try:
                        # (, line 79
                        # [, line 81
                        self.bra = self.cursor
                        # substring, line 81
                        among_var = self.find_among(FrenchStemmer.a_1)
                        if among_var == 0:
                            raise lab2()
                        # ], line 81
                        self.ket = self.cursor
                        if among_var == 1:
                            # (, line 82
                            # <-, line 82
                            if not self.slice_from(u"i"):
                                return False
                        elif among_var == 2:
                            # (, line 83
                            # <-, line 83
                            if not self.slice_from(u"u"):
                                return False
                        elif among_var == 3:
                            # (, line 84
                            # <-, line 84
                            if not self.slice_from(u"y"):
                                return False
                        elif among_var == 4:
                            # (, line 85
                            # <-, line 85
                            if not self.slice_from(u"\u00EB"):
                                return False
                        elif among_var == 5:
                            # (, line 86
                            # <-, line 86
                            if not self.slice_from(u"\u00EF"):
                                return False
                        elif among_var == 6:
                            # (, line 87
                            # delete, line 87
                            if not self.slice_del():
                                return False

                        elif among_var == 7:
                            # (, line 88
                            # next, line 88
                            if self.cursor >= self.limit:
                                raise lab2()
                            self.cursor += 1
                        raise lab1()
                    except lab2: pass
                    self.cursor = v_1
                    raise lab0()
                except lab1: pass
        except lab0: pass
        return True

    def __r_RV(self):
        if not self.I_pV <= self.cursor:
            return False
        return True

    def __r_R1(self):
        if not self.I_p1 <= self.cursor:
            return False
        return True

    def __r_R2(self):
        if not self.I_p2 <= self.cursor:
            return False
        return True

    def __r_standard_suffix(self):
        # (, line 98
        # [, line 99
        self.ket = self.cursor
        # substring, line 99
        among_var = self.find_among_b(FrenchStemmer.a_4)
        if among_var == 0:
            return False
        # ], line 99
        self.bra = self.cursor
        if among_var == 1:
            # (, line 103
            # call R2, line 103
            if not self.__r_R2():
                return False
            # delete, line 103
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 106
            # call R2, line 106
            if not self.__r_R2():
                return False
            # delete, line 106
            if not self.slice_del():
                return False

            # try, line 107
            v_1 = self.limit - self.cursor
            try:
                # (, line 107
                # [, line 107
                self.ket = self.cursor
                # literal, line 107
                if not self.eq_s_b(u"ic"):
                    self.cursor = self.limit - v_1
                    raise lab0()
                # ], line 107
                self.bra = self.cursor
                # or, line 107
                try:
                    v_2 = self.limit - self.cursor
                    try:
                        # (, line 107
                        # call R2, line 107
                        if not self.__r_R2():
                            raise lab2()
                        # delete, line 107
                        if not self.slice_del():
                            return False

                        raise lab1()
                    except lab2: pass
                    self.cursor = self.limit - v_2
                    # <-, line 107
                    if not self.slice_from(u"iqU"):
                        return False
                except lab1: pass
            except lab0: pass
        elif among_var == 3:
            # (, line 111
            # call R2, line 111
            if not self.__r_R2():
                return False
            # <-, line 111
            if not self.slice_from(u"log"):
                return False
        elif among_var == 4:
            # (, line 114
            # call R2, line 114
            if not self.__r_R2():
                return False
            # <-, line 114
            if not self.slice_from(u"u"):
                return False
        elif among_var == 5:
            # (, line 117
            # call R2, line 117
            if not self.__r_R2():
                return False
            # <-, line 117
            if not self.slice_from(u"ent"):
                return False
        elif among_var == 6:
            # (, line 120
            # call RV, line 121
            if not self.__r_RV():
                return False
            # delete, line 121
            if not self.slice_del():
                return False

            # try, line 122
            v_3 = self.limit - self.cursor
            try:
                # (, line 122
                # [, line 123
                self.ket = self.cursor
                # substring, line 123
                among_var = self.find_among_b(FrenchStemmer.a_2)
                if among_var == 0:
                    self.cursor = self.limit - v_3
                    raise lab3()
                # ], line 123
                self.bra = self.cursor
                if among_var == 1:
                    # (, line 124
                    # call R2, line 124
                    if not self.__r_R2():
                        self.cursor = self.limit - v_3
                        raise lab3()
                    # delete, line 124
                    if not self.slice_del():
                        return False

                    # [, line 124
                    self.ket = self.cursor
                    # literal, line 124
                    if not self.eq_s_b(u"at"):
                        self.cursor = self.limit - v_3
                        raise lab3()
                    # ], line 124
                    self.bra = self.cursor
                    # call R2, line 124
                    if not self.__r_R2():
                        self.cursor = self.limit - v_3
                        raise lab3()
                    # delete, line 124
                    if not self.slice_del():
                        return False

                elif among_var == 2:
                    # (, line 125
                    # or, line 125
                    try:
                        v_4 = self.limit - self.cursor
                        try:
                            # (, line 125
                            # call R2, line 125
                            if not self.__r_R2():
                                raise lab5()
                            # delete, line 125
                            if not self.slice_del():
                                return False

                            raise lab4()
                        except lab5: pass
                        self.cursor = self.limit - v_4
                        # (, line 125
                        # call R1, line 125
                        if not self.__r_R1():
                            self.cursor = self.limit - v_3
                            raise lab3()
                        # <-, line 125
                        if not self.slice_from(u"eux"):
                            return False
                    except lab4: pass
                elif among_var == 3:
                    # (, line 127
                    # call R2, line 127
                    if not self.__r_R2():
                        self.cursor = self.limit - v_3
                        raise lab3()
                    # delete, line 127
                    if not self.slice_del():
                        return False

                elif among_var == 4:
                    # (, line 129
                    # call RV, line 129
                    if not self.__r_RV():
                        self.cursor = self.limit - v_3
                        raise lab3()
                    # <-, line 129
                    if not self.slice_from(u"i"):
                        return False
            except lab3: pass
        elif among_var == 7:
            # (, line 135
            # call R2, line 136
            if not self.__r_R2():
                return False
            # delete, line 136
            if not self.slice_del():
                return False

            # try, line 137
            v_5 = self.limit - self.cursor
            try:
                # (, line 137
                # [, line 138
                self.ket = self.cursor
                # substring, line 138
                among_var = self.find_among_b(FrenchStemmer.a_3)
                if among_var == 0:
                    self.cursor = self.limit - v_5
                    raise lab6()
                # ], line 138
                self.bra = self.cursor
                if among_var == 1:
                    # (, line 139
                    # or, line 139
                    try:
                        v_6 = self.limit - self.cursor
                        try:
                            # (, line 139
                            # call R2, line 139
                            if not self.__r_R2():
                                raise lab8()
                            # delete, line 139
                            if not self.slice_del():
                                return False

                            raise lab7()
                        except lab8: pass
                        self.cursor = self.limit - v_6
                        # <-, line 139
                        if not self.slice_from(u"abl"):
                            return False
                    except lab7: pass
                elif among_var == 2:
                    # (, line 140
                    # or, line 140
                    try:
                        v_7 = self.limit - self.cursor
                        try:
                            # (, line 140
                            # call R2, line 140
                            if not self.__r_R2():
                                raise lab10()
                            # delete, line 140
                            if not self.slice_del():
                                return False

                            raise lab9()
                        except lab10: pass
                        self.cursor = self.limit - v_7
                        # <-, line 140
                        if not self.slice_from(u"iqU"):
                            return False
                    except lab9: pass
                elif among_var == 3:
                    # (, line 141
                    # call R2, line 141
                    if not self.__r_R2():
                        self.cursor = self.limit - v_5
                        raise lab6()
                    # delete, line 141
                    if not self.slice_del():
                        return False

            except lab6: pass
        elif among_var == 8:
            # (, line 147
            # call R2, line 148
            if not self.__r_R2():
                return False
            # delete, line 148
            if not self.slice_del():
                return False

            # try, line 149
            v_8 = self.limit - self.cursor
            try:
                # (, line 149
                # [, line 149
                self.ket = self.cursor
                # literal, line 149
                if not self.eq_s_b(u"at"):
                    self.cursor = self.limit - v_8
                    raise lab11()
                # ], line 149
                self.bra = self.cursor
                # call R2, line 149
                if not self.__r_R2():
                    self.cursor = self.limit - v_8
                    raise lab11()
                # delete, line 149
                if not self.slice_del():
                    return False

                # [, line 149
                self.ket = self.cursor
                # literal, line 149
                if not self.eq_s_b(u"ic"):
                    self.cursor = self.limit - v_8
                    raise lab11()
                # ], line 149
                self.bra = self.cursor
                # or, line 149
                try:
                    v_9 = self.limit - self.cursor
                    try:
                        # (, line 149
                        # call R2, line 149
                        if not self.__r_R2():
                            raise lab13()
                        # delete, line 149
                        if not self.slice_del():
                            return False

                        raise lab12()
                    except lab13: pass
                    self.cursor = self.limit - v_9
                    # <-, line 149
                    if not self.slice_from(u"iqU"):
                        return False
                except lab12: pass
            except lab11: pass
        elif among_var == 9:
            # (, line 151
            # <-, line 151
            if not self.slice_from(u"eau"):
                return False
        elif among_var == 10:
            # (, line 152
            # call R1, line 152
            if not self.__r_R1():
                return False
            # <-, line 152
            if not self.slice_from(u"al"):
                return False
        elif among_var == 11:
            # (, line 154
            # or, line 154
            try:
                v_10 = self.limit - self.cursor
                try:
                    # (, line 154
                    # call R2, line 154
                    if not self.__r_R2():
                        raise lab15()
                    # delete, line 154
                    if not self.slice_del():
                        return False

                    raise lab14()
                except lab15: pass
                self.cursor = self.limit - v_10
                # (, line 154
                # call R1, line 154
                if not self.__r_R1():
                    return False
                # <-, line 154
                if not self.slice_from(u"eux"):
                    return False
            except lab14: pass
        elif among_var == 12:
            # (, line 157
            # call R1, line 157
            if not self.__r_R1():
                return False
            if not self.out_grouping_b(FrenchStemmer.g_v, 97, 251):
                return False
            # delete, line 157
            if not self.slice_del():
                return False

        elif among_var == 13:
            # (, line 162
            # call RV, line 162
            if not self.__r_RV():
                return False
            # fail, line 162
            # (, line 162
            # <-, line 162
            if not self.slice_from(u"ant"):
                return False
            return False
        elif among_var == 14:
            # (, line 163
            # call RV, line 163
            if not self.__r_RV():
                return False
            # fail, line 163
            # (, line 163
            # <-, line 163
            if not self.slice_from(u"ent"):
                return False
            return False
        elif among_var == 15:
            # (, line 165
            # test, line 165
            v_11 = self.limit - self.cursor
            # (, line 165
            if not self.in_grouping_b(FrenchStemmer.g_v, 97, 251):
                return False
            # call RV, line 165
            if not self.__r_RV():
                return False
            self.cursor = self.limit - v_11
            # fail, line 165
            # (, line 165
            # delete, line 165
            if not self.slice_del():
                return False

            return False
        return True

    def __r_i_verb_suffix(self):
        # setlimit, line 170
        if self.cursor < self.I_pV:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_pV
        # (, line 170
        # [, line 171
        self.ket = self.cursor
        # substring, line 171
        if self.find_among_b(FrenchStemmer.a_5) == 0:
            self.limit_backward = v_2
            return False
        # ], line 171
        self.bra = self.cursor
        # (, line 177
        # not, line 177
        v_3 = self.limit - self.cursor
        try:
            # literal, line 177
            if not self.eq_s_b(u"H"):
                raise lab0()
            self.limit_backward = v_2
            return False
        except lab0: pass
        self.cursor = self.limit - v_3
        if not self.out_grouping_b(FrenchStemmer.g_v, 97, 251):
            self.limit_backward = v_2
            return False
        # delete, line 177
        if not self.slice_del():
            return False

        self.limit_backward = v_2
        return True

    def __r_verb_suffix(self):
        # setlimit, line 181
        if self.cursor < self.I_pV:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_pV
        # (, line 181
        # [, line 182
        self.ket = self.cursor
        # substring, line 182
        among_var = self.find_among_b(FrenchStemmer.a_6)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        # ], line 182
        self.bra = self.cursor
        if among_var == 1:
            # (, line 184
            # call R2, line 184
            if not self.__r_R2():
                self.limit_backward = v_2
                return False
            # delete, line 184
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 192
            # delete, line 192
            if not self.slice_del():
                return False

        elif among_var == 3:
            # (, line 197
            # delete, line 197
            if not self.slice_del():
                return False

            # try, line 198
            v_3 = self.limit - self.cursor
            try:
                # (, line 198
                # [, line 198
                self.ket = self.cursor
                # literal, line 198
                if not self.eq_s_b(u"e"):
                    self.cursor = self.limit - v_3
                    raise lab0()
                # ], line 198
                self.bra = self.cursor
                # delete, line 198
                if not self.slice_del():
                    return False

            except lab0: pass
        self.limit_backward = v_2
        return True

    def __r_residual_suffix(self):
        # (, line 205
        # try, line 206
        v_1 = self.limit - self.cursor
        try:
            # (, line 206
            # [, line 206
            self.ket = self.cursor
            # literal, line 206
            if not self.eq_s_b(u"s"):
                self.cursor = self.limit - v_1
                raise lab0()
            # ], line 206
            self.bra = self.cursor
            # test, line 206
            v_2 = self.limit - self.cursor
            # (, line 206
            # or, line 206
            try:
                v_3 = self.limit - self.cursor
                try:
                    # literal, line 206
                    if not self.eq_s_b(u"Hi"):
                        raise lab2()
                    raise lab1()
                except lab2: pass
                self.cursor = self.limit - v_3
                if not self.out_grouping_b(FrenchStemmer.g_keep_with_s, 97, 232):
                    self.cursor = self.limit - v_1
                    raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_2
            # delete, line 206
            if not self.slice_del():
                return False

        except lab0: pass
        # setlimit, line 207
        if self.cursor < self.I_pV:
            return False
        v_5 = self.limit_backward
        self.limit_backward = self.I_pV
        # (, line 207
        # [, line 208
        self.ket = self.cursor
        # substring, line 208
        among_var = self.find_among_b(FrenchStemmer.a_7)
        if among_var == 0:
            self.limit_backward = v_5
            return False
        # ], line 208
        self.bra = self.cursor
        if among_var == 1:
            # (, line 209
            # call R2, line 209
            if not self.__r_R2():
                self.limit_backward = v_5
                return False
            # or, line 209
            try:
                v_6 = self.limit - self.cursor
                try:
                    # literal, line 209
                    if not self.eq_s_b(u"s"):
                        raise lab4()
                    raise lab3()
                except lab4: pass
                self.cursor = self.limit - v_6
                # literal, line 209
                if not self.eq_s_b(u"t"):
                    self.limit_backward = v_5
                    return False
            except lab3: pass
            # delete, line 209
            if not self.slice_del():
                return False

        elif among_var == 2:
            # (, line 211
            # <-, line 211
            if not self.slice_from(u"i"):
                return False
        elif among_var == 3:
            # (, line 212
            # delete, line 212
            if not self.slice_del():
                return False

        self.limit_backward = v_5
        return True

    def __r_un_double(self):
        # (, line 217
        # test, line 218
        v_1 = self.limit - self.cursor
        # among, line 218
        if self.find_among_b(FrenchStemmer.a_8) == 0:
            return False
        self.cursor = self.limit - v_1
        # [, line 218
        self.ket = self.cursor
        # next, line 218
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        # ], line 218
        self.bra = self.cursor
        # delete, line 218
        if not self.slice_del():
            return False

        return True

    def __r_un_accent(self):
        # (, line 221
        # atleast, line 222
        v_1 = 1
        # atleast, line 222
        try:
            while True:
                try:
                    try:
                        if not self.out_grouping_b(FrenchStemmer.g_v, 97, 251):
                            raise lab2()
                        v_1 -= 1
                        raise lab1()
                    except lab2: pass
                    raise lab0()
                except lab1: pass
        except lab0: pass
        if v_1 > 0:
            return False
        # [, line 223
        self.ket = self.cursor
        # or, line 223
        try:
            v_3 = self.limit - self.cursor
            try:
                # literal, line 223
                if not self.eq_s_b(u"\u00E9"):
                    raise lab4()
                raise lab3()
            except lab4: pass
            self.cursor = self.limit - v_3
            # literal, line 223
            if not self.eq_s_b(u"\u00E8"):
                return False
        except lab3: pass
        # ], line 223
        self.bra = self.cursor
        # <-, line 223
        if not self.slice_from(u"e"):
            return False
        return True

    def _stem(self):
        # (, line 227
        # do, line 229
        v_1 = self.cursor
        # call prelude, line 229
        self.__r_prelude()
        self.cursor = v_1
        # do, line 230
        # call mark_regions, line 230
        self.__r_mark_regions()
        # backwards, line 231
        self.limit_backward = self.cursor
        self.cursor = self.limit
        # (, line 231
        # do, line 233
        v_3 = self.limit - self.cursor
        try:
            # (, line 233
            # or, line 243
            try:
                v_4 = self.limit - self.cursor
                try:
                    # (, line 234
                    # and, line 239
                    v_5 = self.limit - self.cursor
                    # (, line 235
                    # or, line 235
                    try:
                        v_6 = self.limit - self.cursor
                        try:
                            # call standard_suffix, line 235
                            if not self.__r_standard_suffix():
                                raise lab4()
                            raise lab3()
                        except lab4: pass
                        self.cursor = self.limit - v_6
                        try:
                            # call i_verb_suffix, line 236
                            if not self.__r_i_verb_suffix():
                                raise lab5()
                            raise lab3()
                        except lab5: pass
                        self.cursor = self.limit - v_6
                        # call verb_suffix, line 237
                        if not self.__r_verb_suffix():
                            raise lab2()
                    except lab3: pass
                    self.cursor = self.limit - v_5
                    # try, line 240
                    v_7 = self.limit - self.cursor
                    try:
                        # (, line 240
                        # [, line 240
                        self.ket = self.cursor
                        # or, line 240
                        try:
                            v_8 = self.limit - self.cursor
                            try:
                                # (, line 240
                                # literal, line 240
                                if not self.eq_s_b(u"Y"):
                                    raise lab8()
                                # ], line 240
                                self.bra = self.cursor
                                # <-, line 240
                                if not self.slice_from(u"i"):
                                    return False
                                raise lab7()
                            except lab8: pass
                            self.cursor = self.limit - v_8
                            # (, line 241
                            # literal, line 241
                            if not self.eq_s_b(u"\u00E7"):
                                self.cursor = self.limit - v_7
                                raise lab6()
                            # ], line 241
                            self.bra = self.cursor
                            # <-, line 241
                            if not self.slice_from(u"c"):
                                return False
                        except lab7: pass
                    except lab6: pass
                    raise lab1()
                except lab2: pass
                self.cursor = self.limit - v_4
                # call residual_suffix, line 244
                if not self.__r_residual_suffix():
                    raise lab0()
            except lab1: pass
        except lab0: pass
        self.cursor = self.limit - v_3
        # do, line 249
        v_9 = self.limit - self.cursor
        # call un_double, line 249
        self.__r_un_double()
        self.cursor = self.limit - v_9
        # do, line 250
        v_10 = self.limit - self.cursor
        # call un_accent, line 250
        self.__r_un_accent()
        self.cursor = self.limit - v_10
        self.cursor = self.limit_backward
        # do, line 252
        v_11 = self.cursor
        # call postlude, line 252
        self.__r_postlude()
        self.cursor = v_11
        return True


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass


class lab5(BaseException): pass


class lab6(BaseException): pass


class lab7(BaseException): pass


class lab8(BaseException): pass


class lab9(BaseException): pass


class lab10(BaseException): pass


class lab11(BaseException): pass


class lab12(BaseException): pass


class lab13(BaseException): pass


class lab14(BaseException): pass


class lab15(BaseException): pass
